@@ -22,7 +22,7 @@ using System;
 using System.IO; 
 using System.Linq;
 using System.Collections.Generic;
-using Mono.Unix;
+using Mono.Addins;
 
 using Do.Platform;
 using Do.Universe;
@@ -35,16 +35,16 @@ namespace Locate
 		
 		bool allowHidden = false;
 		const uint maxResults = 500;
-		string Error = Catalog.GetString ("Locate found 0 files for: ");
+		string Error = AddinManager.CurrentLocalizer.GetString ("Locate found 0 files for: ");
 		
 		public override string Name
 		{
-			get { return Catalog.GetString ("Locate Files"); }
+			get { return AddinManager.CurrentLocalizer.GetString ("Locate Files"); }
 		}
 		
 		public override string Description
 		{
-			get { return Catalog.GetString ("Search your filesystem using locate."); }
+			get { return AddinManager.CurrentLocalizer.GetString ("Search your filesystem using locate."); }
 		}
 		
 		public override string Icon
@@ -67,6 +67,13 @@ namespace Locate
 				
 			files = new List<Item> ();
 			query = (items.First () as ITextItem).Text;
+
+			if (string.IsNullOrEmpty(query))
+			{
+				Services.Notifications.Notify("Locate Files",
+					"No text provided for searching.");
+				yield break;
+			}
 			
 			locate = new System.Diagnostics.Process ();
 			locate.StartInfo.FileName = "locate";
@@ -90,13 +97,15 @@ namespace Locate
 				results++;
 				files.Add (Services.UniverseFactory.NewFileItem (path) as Item);
 			}
+			
 			if (results > 0) {
 				files.Sort (new IFileItemNameComparer (query));
 				foreach (Item file in files)
 					yield return file;
+			} else {
+				Services.Notifications.Notify ("Locate Files", Error + query);
+				yield break;
 			}
-			else
-				yield return new TextItem (Error + query);
 		}
 
 		// Order files by (A) position of query in the file name and
