@@ -18,39 +18,35 @@
 //  this program.  If not, see <http://www.gnu.org/licenses/>.
 
 using System;
+using System.Xml.Serialization;
+
+using Do.Universe;
 
 namespace Pastebin
 {
-	public class TextSyntaxItem : ITextSyntaxItem
-	{	
-		private string name, description, icon, syntax;		
-		
-		public TextSyntaxItem (string name, string description, string icon, string syntax)
+	public class TextSyntaxItem : Item, ITextSyntaxItem
+	{		
+		public TextSyntaxItem ()
 		{
-			this.name = name;
-			this.description = description;
-			this.icon = icon;
-			this.syntax = syntax;
 		}
 		
-		public string Name
-		{
-			get { return name; }
-		}
+		[XmlIgnore]
+		public override string Name { get { return SerializableName; } }
 		
-		public string Description
-		{
-			get { return description; }
-		}
+		[XmlIgnore]
+		public override string Description { get { return SerializableDescription; } }
+		
+		[XmlIgnore]
+		public override string Icon { get { return SerializableIcon; } }
+
+		public string Syntax { get; set; }
+		
+		public string SerializableName { get; set; }
+		
+		public string SerializableDescription { get; set; }
+		
+		public string SerializableIcon { get; set; }
 		
-		public string Icon
-		{
-			get { return icon; }
-		}
 		
-		public string Syntax
-		{
-			get { return syntax; }
-		}
 	}
 }
