@@ -19,6 +19,7 @@
 
 using System;
 using System.IO;
+using System.Linq;
 using System.Diagnostics;
 using System.Collections.Generic;
 
@@ -26,6 +27,7 @@ using NDesk.DBus;
 using org.freedesktop.DBus;
 
 using Do.Platform;
+using Do.Universe;
 
 namespace PidginPlugin
 {
@@ -39,35 +41,44 @@ namespace PidginPlugin
 		[Interface ("im.pidgin.purple.PurpleInterface")]
 		public interface IPurpleObject
 		{
-			int [] PurpleAccountsGetAllActive ();
 			int[] PurpleAccountsGetAll ();
+			int PurpleBuddyGetIcon (int buddy);
+			int[] PurpleAccountsGetAllActive ();
 			bool PurpleBuddyIsOnline (int buddy);
 			int PurpleBuddyGetAccount (int buddy);
-			bool PurpleAccountIsConnected (int account);
-			int PurpleFindBuddy (int account, string name);
-			void PurpleConversationPresent (int conversation);
-			int PurpleAccountsFindConnected (string account, string proto);
-			int PurpleConversationNew (int type, int account, string name);
-			int PurpleSavedstatusNew (string title, int type);
-			void PurpleSavedstatusSetMessage (int type, string message);
-			void PurpleSavedstatusActivate (int status);
-			int [] PurpleSavedstatusesGetAll ();
-			bool PurpleSavedstatusIsTransient (int saved_status);
-			int PurpleSavedstatusGetType (int saved_status);
-			string PurpleSavedstatusGetMessage (int saved_status);
-			string PurpleSavedstatusGetTitle (int saved_status);
-			int PurpleSavedstatusGetCurrent ();
-			int PurpleSavedstatusFind (string title);
-			string PurpleAccountGetProtocolName (int account);
 			string PurpleAccountGetAlias (int account);
-			void PurpleAccountSetEnabled (int account, string ui, int value);
+			bool PurpleAccountIsConnected (int account);
+			string PurpleBuddyGetLocalAlias (int buddy);
+			string PurpleBuddyGetServerAlias (int buddy);
+			string PurpleBuddyIconGetFullPath (int icon);
 			string PurpleAccountGetUsername (int account);
+			int PurpleFindBuddy (int account, string name);
+			string PurpleAccountGetProtocolName (int account);
+			int[] PurpleFindBuddies (int account, string name);
+			int PurpleAccountsFindConnected (string account, string proto);
+			void PurpleAccountSetEnabled (int account, string ui, int val);
+
+			int PurpleSavedstatusGetCurrent ();
+			int [] PurpleSavedstatusesGetAll ();
+			int PurpleSavedstatusFind (string title);
+			void PurpleSavedstatusActivate (int status);
+			int PurpleSavedstatusGetType (int saved_status);
+			int PurpleSavedstatusNew (string title, int type);
+			string PurpleSavedstatusGetTitle (int saved_status);
+			bool PurpleSavedstatusIsTransient (int saved_status);
+			string PurpleSavedstatusGetMessage (int saved_status);
+			void PurpleSavedstatusSetMessage (int type, string message);
+			
+			int PurpleConversationGetImData (int conv);
+			void PurpleConvImSend (int im, string message);
+			void PurpleConversationPresent (int conversation);
+			int PurpleConversationNew (int type, int account, string name);
 			
 			#region Pidgin < 2.5.4 compatibility methods
 			
-			int PurpleConversationNew (uint type, int account, string name);
 			int PurpleSavedstatusNew (string title, uint type);
-			void PurpleAccountSetEnabled (int account, string ui, uint value);
+			int PurpleConversationNew (uint type, int account, string name);
+			void PurpleAccountSetEnabled (int account, string ui, uint val);
 			
 			#endregion
 		}
@@ -75,18 +86,38 @@ namespace PidginPlugin
 		public static string ChatIcon {
 			get { return "internet-group-chat.svg@" + typeof (Pidgin).Assembly.FullName; }
 		}
+		
+		public static bool IsPidgin (Item item) 
+		{
+			return item.Equals (Do.Platform.Services.UniverseFactory.MaybeApplicationItemFromCommand ("pidgin"));
+		}
 
 		public static string GetProtocolIcon (string proto)
 		{
-			string icon;
+			string icon = null;
 
 			proto = proto.ToLower ();
-			if (proto.StartsWith ("prpl-"))
-				proto = proto.Substring ("prpl-".Length);
-			icon = Path.Combine (
-				"/usr/share/pixmaps/pidgin/protocols/48", proto + ".png");
+			string[] parts = proto.Split ('-');
+			
+			if (parts.Length >= 2) {
+				if (parts[0] == "prpl")
+					proto = parts[1];
+			}
+			icon = Path.Combine ("/usr/share/pixmaps/pidgin/protocols/48", proto + ".png");
 			return File.Exists (icon) ? icon : Pidgin.ChatIcon;
 		}
+		
+		public static string GetBuddyIconPath (int buddyID)
+		{
+			IPurpleObject prpl = GetPurpleObject ();
+
+			int icon = prpl.PurpleBuddyGetIcon (buddyID);
+			if (icon == 0) 
+				return null;
+			
+			string iconPath = prpl.PurpleBuddyIconGetFullPath (icon);
+			return (File.Exists (iconPath)) ? iconPath : null;
+		}
 
 		public static IPurpleObject GetPurpleObject ()
 		{
@@ -97,23 +128,78 @@ namespace PidginPlugin
 				return null;
 			}
 		}
-
-		private static int [] ConnectedAccounts {
+		
+		private static IEnumerable<int> ConnectedAccounts {
 			get {
-				List<int> connected;
-				IPurpleObject prpl;
+				IPurpleObject prpl = GetPurpleObject ();
 
-				prpl = GetPurpleObject ();
-				connected = new List<int> ();
-				try {
-					foreach (int account in prpl.PurpleAccountsGetAllActive ()) {
-						if (prpl.PurpleAccountIsConnected (account))
-							connected.Add (account);
-					}
-				} catch { }
-				return connected.ToArray ();
+				return prpl.PurpleAccountsGetAllActive ().Where (acct => prpl.PurpleAccountIsConnected (acct));
 			}
 		}
+		
+		public static int GetAccountID (string name, string proto) 
+		{
+			IPurpleObject prpl = GetPurpleObject ();
+			int account;
+			try {
+				account = prpl.PurpleAccountsFindConnected (name, proto); 
+			} catch { 
+				account = -1;
+			}			
+			return account;
+		}
+		
+		public static IEnumerable<int> FindBuddies (int account, string name)
+		{
+			IPurpleObject prpl = GetPurpleObject ();	
+
+			return prpl.PurpleFindBuddies (account, name);
+		}
+		
+		public static string GetBuddyLocalAlias (int buddy)
+		{
+			IPurpleObject prpl = GetPurpleObject ();
+			
+			if (!InstanceIsRunning)
+				return null;
+				
+			//don't need to do too much error checking here,
+			//this method should always return something and it's only used
+			//for bonjour, which _will_ always return what I'm looking for.
+			return prpl.PurpleBuddyGetLocalAlias (buddy);
+		}
+		
+		public static string GetBuddyServerAlias (string name)
+		{
+			IPurpleObject prpl = GetPurpleObject ();
+			int buddy;
+			string alias;
+			
+			if (!InstanceIsRunning)
+				return null;
+			
+			foreach (int account in ConnectedAccounts) {
+				buddy = prpl.PurpleFindBuddy (account, name);
+				
+				if (buddy == 0) 
+					continue;
+				
+				alias = prpl.PurpleBuddyGetServerAlias (buddy);
+				return string.IsNullOrEmpty (alias) ? null : alias;
+			}
+			return null;
+		}
+		
+		public static string GetBuddyServerAlias (int buddy)
+		{
+			IPurpleObject prpl = GetPurpleObject ();
+			
+			if (!InstanceIsRunning)
+				return null;
+			
+			string alias = prpl.PurpleBuddyGetServerAlias (buddy);
+			return string.IsNullOrEmpty (alias) ? null : alias;
+		}
 
 		public static bool BuddyIsOnline (string name)
 		{
@@ -127,16 +213,17 @@ namespace PidginPlugin
 			int buddy;
 		   
 			prpl = GetPurpleObject ();
+			account_out = -1;
+			
 			try {
 				foreach (int account in ConnectedAccounts) {
 					buddy = prpl.PurpleFindBuddy (account, name);
-					if (prpl.PurpleBuddyIsOnline (buddy)) {
+					if (buddy != 0)
 						account_out = account;
+					if (prpl.PurpleBuddyIsOnline (buddy))
 						return true;
-					}
 				}
 			} catch { }
-			account_out = -1;
 			return false;
 		}
 		
@@ -148,7 +235,7 @@ namespace PidginPlugin
 			Away = 5,
 		}
 		
-		public static void PurpleSetAvailabilityStatus  (uint kind, string message)
+		public static void PurpleSetAvailabilityStatus  (int kind, string message)
 		{
 			IPurpleObject prpl;
 			
@@ -163,11 +250,13 @@ namespace PidginPlugin
 				}
 				prpl.PurpleSavedstatusSetMessage (status, message);
 				prpl.PurpleSavedstatusActivate (status);
-			} catch {
+			} catch (Exception e) {
+				Log<Pidgin>.Error ("Could set Pidgin status: {0}", e.Message);
+				Log<Pidgin>.Debug (e.StackTrace);
 			}
 		}
-
-		public static void OpenConversationWithBuddy (string name)
+		
+		public static void OpenConversationWithBuddy (string name, string message)
 		{
 			int account, conversation;
 			IPurpleObject prpl;
@@ -176,13 +265,17 @@ namespace PidginPlugin
 			try {
 				GetBuddyIsOnlineAndAccount (name, out account);
 				if (account == -1)
-					account = prpl.PurpleAccountsFindConnected ("", "");
+					throw new ArgumentException ();
 				try {
 					conversation = prpl.PurpleConversationNew ((int) 1, account, name);
 				}
 				catch {
 					conversation = prpl.PurpleConversationNew ((uint) 1, account, name);
 				}
+				if (!string.IsNullOrEmpty (message)) {
+					int im = prpl.PurpleConversationGetImData (conversation);
+					prpl.PurpleConvImSend (im, message);
+				}
 				prpl.PurpleConversationPresent (conversation);
 			} catch (Exception e) {
 				Log<Pidgin>.Error ("Could not create new Pidgin conversation: {0}", e.Message);
@@ -190,17 +283,26 @@ namespace PidginPlugin
 			}
 		}
 
+		public static void OpenConversationWithBuddy (string name)
+		{
+			OpenConversationWithBuddy (name, "");
+		}
+
 		public static bool InstanceIsRunning
 		{
 			get {
 				Process pidof;
-				
+				ProcessStartInfo pidofInfo = new ProcessStartInfo ("pidof", "pidgin");
+				pidofInfo.UseShellExecute = false;
+				pidofInfo.RedirectStandardError = true;
+				pidofInfo.RedirectStandardOutput = true;
+								
 				try {
 					// Use pidof command to look for pidgin process. Exit
 					// status is 0 if at least one matching process is found.
 					// If there's any error, just assume some Purple client
 					// is running.
-					pidof = Process.Start ("pidof", "pidgin");
+					pidof = Process.Start (pidofInfo);
 					pidof.WaitForExit ();
 					return pidof.ExitCode == 0;
 				} catch {
