@@ -21,9 +21,11 @@
 //
 
 using System;
+using System.Collections.Generic;
 using Wnck;
 
 using Do.Universe;
+using Do.Interface.Wink;
 
 namespace WindowManager
 {
@@ -31,12 +33,17 @@ namespace WindowManager
 //	{
 //	}
 	
-	public interface IWindowItem : IItem
+	public interface IWindowItem
 	{
-		Wnck.Window Window { get; }
+		IEnumerable<Wnck.Window> Windows { get; }
 	}
 	
-	public interface IScreenItem : IItem
+	public interface IScreenItem
 	{
+		Viewport Viewport { get; }
+		
+		IEnumerable<Wnck.Window> Windows { get; }
+		
+		IEnumerable<Wnck.Window> VisibleWindows { get; }
 	}
 }
