@@ -22,10 +22,13 @@
 
 using System;
 using System.Collections.Generic;
+using System.Linq;
 
 using Do.Universe;
+using Do.Interface.Wink;
+
 using Wnck;
-using Mono.Unix;
+using Mono.Addins;
 
 namespace WindowManager
 {
@@ -35,13 +38,13 @@ namespace WindowManager
 		
 		public override string Name {
 			get {
-				return Catalog.GetString ("Generic Window Items");
+				return AddinManager.CurrentLocalizer.GetString ("Generic Window Items");
 			}
 		}
 
 		public override string Description {
 			get {
-				return Catalog.GetString ("Useful Generically Understood Window Items");
+				return AddinManager.CurrentLocalizer.GetString ("Useful Generically Understood Window Items");
 			}
 		}
 
@@ -54,7 +57,8 @@ namespace WindowManager
 		public override IEnumerable<Type> SupportedItemTypes {
 			get {
 				return new Type [] {
-					typeof (GenericWindowItem)};
+					typeof (IApplicationItem),
+				};
 			}
 		}
 
@@ -66,34 +70,27 @@ namespace WindowManager
 
 		public WindowItemSource ()
 		{
+			WindowUtils.Initialize ();
 			items = new List<Item> ();
-			
-			items.Add (new GenericWindowItem (Catalog.GetString ("Current Window"),
-			                                  Catalog.GetString ("The Currently Active Window"),
-			                                  "gnome-window-manager",
-			                                  GenericWindowType.CurrentWindow));
-			items.Add (new GenericWindowItem (Catalog.GetString ("Current Application"),
-			                                  Catalog.GetString ("The Currently Active Application"),
-			                                  "gnome-window-manager",
-			                                  GenericWindowType.CurrentApplication));
-			items.Add (new GenericWindowItem (Catalog.GetString ("Previous Window"),
-			                                  Catalog.GetString ("The Previously Active Window"),
-			                                  "gnome-window-manager",
-			                                  GenericWindowType.PreviousWindow));
-			items.Add (new GenericWindowItem (Catalog.GetString ("Previous Application"),
-			                                  Catalog.GetString ("The Previously Active Application"),
-			                                  "gnome-window-manager",
-			                                  GenericWindowType.PreviousApplication));
+			items.Add (new CurrentApplicationItem ());
+			items.Add (new CurrentWindowItem ());
 		}
 		
 		public override IEnumerable<Item> ChildrenOfItem (Item item)
 		{
-			return null;
-		}
-
-		public override void UpdateItems ()
-		{
-			return;
-		}		
+			List<Item> results = new List<Item> ();
+			IApplicationItem app = item as IApplicationItem;
+			if (app == null)
+				return results;
+			
+			List<Wnck.Window> windows = WindowUtils.WindowListForCmd (app.Exec);
+			if (!windows.Any ())
+				return results;
+			
+			foreach (Wnck.Window window in windows)
+				results.Add (new WindowItem (window, app.Icon));
+			
+			return results;
+		}	
 	}
 }
